import productGroup from "./prduct-group"
import imageCube from './image-cube.ts'
import { createUniqueId } from '../engineer/utils'
import { Category } from '../engineer'

export default {
  icon: 'trash',
  text: '基础',
  modules: [
    {
      vid: createUniqueId(),
      mid: createUniqueId(),
      title: '轮播图',
      maxReferenceCount: -1,
      referenceCount: 0,
      image: undefined,
      configs: [
        {
          type: 'list',
          field: 'items',
          label: '轮播图设置',
          help: '最多可添加10张图片，建议宽度750px；鼠标拖拽左侧圆点可调整图片顺序',
          addable: true,
          configs: [{
            type: 'image',
            field: 'image',
            label: '图片',
            required: true,
            // 表示内联数据
            inlines: [{
              type: 'text',
              field: 'title',
              label: '标题',
              help: '选填，不超过 4 个字',
            }, {
              type: 'text',
              field: 'link',
              label: '链接',
              help: '请输入链接', // 自动生成："请输入${label}"
            }],
          }],
        },
        {
          type: 'object',
          field: 'indicator',
          label: '指示器',
          configs: [{
            type: 'mark',
            field: 'style',
            label: '指示器样式',
            values: [
              { label: '圆形', value: '#circle' },
              { label: '直线', value: '#line' },
              { label: '数字', value: '#number' },
            ],
          }, {
            type: 'mark',
            field: 'position',
            label: '指示器位置',
            values: [
              { label: '居左', value: 'start' },
              { label: '居中', value: 'center' },
              { label: '居右', value: 'end' },
            ],
          },
            {
              type: 'color',
              field: 'color',
              label: '指示器颜色',
            }],
        },
        {
          type: 'object',
          field: 'background',
          label: '背景',
          configs: [{
            type: 'boolean',
            field: 'enabled',
            label: '是否显示背景色',
          }, {
            type: 'background',
            field: 'value',
            // 背景的不同实现方式，可以在里面添加 image 选项来支持图片
            // 这里只能支持颜色和渐变，
            features: ['color', 'gradient'],
            label: '背景',
          }],
        }
      ],
      init: {
        items: [
          {
            image: '',
            title: '123',
            link: '123',
          }
        ],
        indicator: {
          style: '#circle',
          color: 'green',
          position: 'start',
        },
        background: {
          enabled: true,
          value: "#ffffff",
        },
        theme: {
          color: 'white',
          radius: 24
        }
      },
      templates: {
        '#circle': {
          theme: {
            gap: 20,
          },
          children: {
            type: 'each',
            key: 'items',
            handle: {
              theme: {
                width: 20,
                height: 20,
                radius: 10,
                color: '@@indicator.color',
              },
            }
          }
        },
        '#line': {
          theme: {
            gap: 20,
          },
          children: {
            type: 'each',
            key: 'items',
            handle: {
              theme: {
                width: 40,
                height: 20,
                color: '@@indicator.color',
              },
            }
          }
        },
        "#number": {
          theme: {
            color: 'rgba(0,0,0,0.4)',
            textColor: '#fff'
          },
          children: '1/len(items)'
        }
      },
      theme: {
        position: 'relative',
        height: 200,
        padding: {
          horizontal: 12.0,
          vertical: 12,
        },
        color: 'cyan',
      },
      children: [
        {
          vid: createUniqueId(),
          theme: {
            width: '100%',
            height: '100%',
            color: '@@theme.color',
            radius: "@@theme.radius",
            textAlign: 'center',
          },
          children: '设置轮播图',
        },
        {
          theme: {
            position: 'absolute',
            flexible: true,
            mainAlign: '@@indicator.position',
            bottom: 20,
            left: 20,
            right: 20,
            height: 20,
            color: 'red',
          },
          children: {
            type: 'template',
            key: 'indicator.style'
          }
        }],
    },
    productGroup,
    {
      title: '产品分类',
      vid: createUniqueId(),
      mid: createUniqueId(),
      maxReferenceCount: -1,
      referenceCount: 0,
      image: undefined,
      configs: [
        {
          help: '帮助',
          addable: true,
          type: 'list',
          field: 'items',
          label: '产品分类列表',
          configs: [
            {
              type: 'image',
              label: '分类图片',
              field: 'itemImage',
              // 表示内联数据
              inlines: [{
                type: 'text',
                field: 'link',
                label: '链接',
                help: '请输入链接', // 自动生成："请输入${label}"
              },
                {
                  type: 'text',
                  label: '自定义标题',
                  field: 'title',
                },
              ]
            },
          ]
        },
      ],
      init: {
        theme: {
          color: '#fff',
        },
        items: [
          {
            title: '标题',
            link: 'link'
          }
        ]
      },
      theme: {
        padding: 12,
        color: '@@theme.color',
      },
      children: {
        theme: {
          width: '100%',
          clip: 'autoX',
          whiteSpace: 'nowrap',
        },
        children: {
          type: 'each',
          key: 'items',
          handle: {
            theme: {
              width: '60px',
              height: '60px',
              display: 'inline-block',
              radius: 40,
              color: 'pink',
              textColor: '#fff',
              margin: {
                right: 10
              },
            },
            children: '图片',
          }
        },
      }
    },
    {
      title: '两列产品卡片',
      vid: createUniqueId(),
      mid: createUniqueId(),
      maxReferenceCount: -1,
      referenceCount: 0,
      image: undefined,
      configs: [],
      init: {},
      theme: {
        color: 'pink',
        padding: {
          top: 12.5,
          left: 12.5,
          right: 12.5
        },
        gap: 10,
      },
      children: [
        {
          theme: {
            width: 170,
            height: 200,
            color: 'white'
          },
          children: '产品'
        },
        {
          theme: {
            width: 170,
            height: 200,
            color: 'white'
          },
          children: '产品'
        }
      ]
    },
    {
      title: '自定义标题',
      vid: createUniqueId(),
      mid: createUniqueId(),
      maxReferenceCount: -1,
      referenceCount: 0,
      image: undefined,
      configs: [
        {
          type: 'text',
          field: 'Title',
          label: '标题',
          help: '自定义标题', // 自动生成："请输入${label}"
        },
      ],
      init: {
        Title: '猜你喜欢',
      },
      theme: {
        padding: {
          vertical: 15,
          horizontal: 15,
        },
        color: '#fff',
        textColor: '#333',
        fontSize: '@@theme.fontSize',
        fontWeight: 900,
      },
      children: {
        type: 'text',
        key: 'Title'
      }

    },
    {
      title: '搜索框',
      vid: createUniqueId(),
      mid: createUniqueId(),
      maxReferenceCount: -1,
      referenceCount: 0,
      image: undefined,
      configs: [
        {
          type: 'object',
          field: 'search',
          label: '搜索框',
          configs: [
            {
              required: true,
              type: 'text',
              label: '搜索框内容',
              field: 'innerText'
            },
            {
              type: 'boolean',
              field: 'showLogo',
              label: '是否展示左侧logo',
            }, {
              type: 'image',
              field: 'logoImg',
              label: '左侧logo',
            }
          ]
        },
      ],
      init: {},
      templates: {
        'true': {
          theme: {},
          children: 'logo'
        },
        'false': {
          theme: {},
          children: ''
        }
      },
      theme: {
        display: 'flex',
        crossAlign: 'center',
        padding: {
          horizontal: 15,
          vertical: 8,
        },
        color: 'cyan'
      },
      children: [
        {
          children: {
            type: 'template',
            key: 'search.showLogo'
          },
        },
        {
          theme: { width: 10 },
        },
        {
          theme: {
            width: '60%',
            color: 'white',
            radius: 30.0,
            padding: {
              horizontal: 10,
              vertical: 5,
            },
            fontSize: 14,
          },
          children: '猜你喜欢'
        }
      ]
    },
    imageCube,
    {
      title: '商品分类',
      vid: createUniqueId(),
      mid: createUniqueId(),
      maxReferenceCount: -1,
      referenceCount: 0,
      image: undefined,
      init: {},
      templates:{},
      configs:[],
      theme:{
        color: 'white',
        gap: 15,
        fontSize:14,
        fontWeight: 400,
        padding:10,
      },
      children:[
        {children:'产品分类',theme:{fontWeight:600}},
        {children:'产品分类'},
        {children:'产品分类'},
        {children:'产品分类'},
        {children:'产品分类'},
      ],
    }


  ],
} as Category
